@@ -9,15 +9,15 @@ use Net::OpenSSH;
 use Cinnamon::HandleManager;
 use Cinnamon::Logger;
 
+has [qw(host user)] => (is => 'ro');
+
 sub connection {
     my $self = shift;
     return Net::OpenSSH->new(
-        $self->{host}, user => $self->{user},
+        $self->host, user => $self->user,
     );
 }
 
-sub host { $_[0]->{host} }
-
 sub execute {
     my ($self, $commands, $opts) = @_;
     my $host = $self->host || '';
@@ -35,7 +35,7 @@ sub execute {
         print $stdin "$opts->{password}\n";
     }
 
-    my $hm = Cinnamon::HandleManager->new(host => $self->{host});
+    my $hm = Cinnamon::HandleManager->new(host => $self->host);
     $hm->register_fh(stdout => $stdout);
     $hm->register_fh(stderr => $stderr);
     $hm->start_async_read();
